---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment (please complete the following information):**
 - OS [e.g. Linux, Windows 10]
 - Python version [e.g. 3.7]
 - Version [e.g. 0.1.1]

**Log**
Paste any error messages or logs associated with the bug here.

**Additional context**
Add any other context about the problem here.